@@ -21,6 +21,18 @@ sub __DependsOn
     my $deps = $args{'Dependencies'};
     my $list = [];
 
+# Scrips
+    my $objs = RT::Scrips->new( $self->CurrentUser );
+    $objs->Limit( FIELD => 'Template', VALUE => $self->Id );
+    push( @$list, $objs );
+
+    $deps->_PushDependencies(
+        BaseObject => $self,
+        Flags => DEPENDS_ON,
+        TargetObjects => $list,
+        Shredder => $args{'Shredder'},
+    );
+
     return $self->SUPER::__DependsOn( %args );
 }
 
